# Licensed to Elasticsearch B.V. under one or more contributor
# license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#
# Auto generated from build hash f284cc16f4d4b4289bc679aa1529bb504190fe80
# @see https://github.com/elastic/elasticsearch/tree/main/rest-api-spec
#
module Elasticsearch
  module API
    module Security
      module Actions
        # Evicts users from the user cache. Can completely clear the cache or evict specific users.
        #
        # @option arguments [List] :realms Comma-separated list of realms to clear
        # @option arguments [List] :usernames Comma-separated list of usernames to clear from the cache
        # @option arguments [Hash] :headers Custom HTTP headers
        #
        # @see https://www.elastic.co/guide/en/elasticsearch/reference/8.11/security-api-clear-cache.html
        #
        def clear_cached_realms(arguments = {})
          request_opts = { endpoint: arguments[:endpoint] || "security.clear_cached_realms" }

          defined_params = [:realms].inject({}) do |set_variables, variable|
            set_variables[variable] = arguments[variable] if arguments.key?(variable)
            set_variables
          end
          request_opts[:defined_params] = defined_params unless defined_params.empty?

          raise ArgumentError, "Required argument 'realms' missing" unless arguments[:realms]

          arguments = arguments.clone
          headers = arguments.delete(:headers) || {}

          body = nil

          _realms = arguments.delete(:realms)

          method = Elasticsearch::API::HTTP_POST
          path   = "_security/realm/#{Utils.__listify(_realms)}/_clear_cache"
          params = Utils.process_params(arguments)

          Elasticsearch::API::Response.new(
            perform_request(method, path, params, body, headers, request_opts)
          )
        end
      end
    end
  end
end
